biom.table.Table — biom-format.org

# biom-format.org

## biom.table.Table

class `biom.table.` `Table`(data, observation_ids, sample_ids, observation_metadata=None, sample_metadata=None, table_id=None, type=None, create_date=None, generated_by=None, observation_group_metadata=None, sample_group_metadata=None, **kwargs)

  The (canonically pronounced ‘teh’) Table.

  Give in to the power of the Table!

  Attributes

  `dtype` | The type of the objects in the underlying contingency matrix
  `matrix_data` | The sparse matrix object
  `nnz` | Number of non-zero elements of the underlying contingency matrix
  `shape` | The shape of the underlying contingency matrix

  Methods

  `__getitem__`(args) | Handles row or column slices
  `_extract_data_from_tsv`(lines[, delim, ...]) | Parse a classic table into (sample_ids, obs_ids, data, metadata,
  `add_group_metadata`(group_md[, axis]) | Take a dict of group metadata and add it to an axis
  `add_metadata`(md[, axis]) | Take a dict of metadata and add it to an axis.
  `collapse`(f[, collapse_f, norm, ...]) | Collapse partitions in a table by metadata or by IDs
  `copy`() | Returns a copy of the table
  `data`(id[, axis, dense]) | Returns data associated with an id
  `delimited_self`([delim, header_key, ...]) | Return self as a string in a delimited form
  `descriptive_equality`(other) | For use in testing, describe how the tables are not equal
  `exists`(id[, axis]) | Returns whether id exists in axis
  `filter`(ids_to_keep[, axis, invert, inplace]) | Filter a table based on a function or iterable.
  `from_hdf5`(h5grp[, ids, axis]) | Parse an HDF5 formatted BIOM table
  `from_json`(json_table[, data_pump, ...]) | Parse a biom otu table type
  `from_tsv`(lines, obs_mapping, sample_mapping, ...) | Parse a tab separated (observation x sample) formatted BIOM table
  `get_table_density`() | Returns the fraction of nonzero elements in the table.
  `get_value_by_ids`(obs_id, samp_id) | Return value in the matrix corresponding to `(obs_id, samp_id)`
  `group_metadata`([axis]) | Return the group metadata of the given axis
  `ids`([axis]) | Return the ids along the given axis
  `index`(id, axis) | Return the index of the identified sample/observation.
  `is_empty`() | Check whether the table is empty
  `iter`([dense, axis]) | Yields `(value, id, metadata)`
  `iter_data`([dense, axis]) | Yields axis values
  `iter_pairwise`([dense, axis, tri, diag]) | Pairwise iteration over self
  `length`([axis]) | Return the length of an axis
  `max`([axis]) | Get the maximum nonzero value over an axis
  `merge`(other[, sample, observation, ...]) | Merge two tables together
  `metadata`([id, axis]) | Return the metadata of the identified sample/observation.
  `min`([axis]) | Get the minimum nonzero value over an axis
  `nonzero`() | Yields locations of nonzero elements within the data matrix
  `nonzero_counts`(axis[, binary]) | Get nonzero summaries about an axis
  `norm`([axis, inplace]) | Normalize in place sample values by an observation, or vice versa.
  `pa`([inplace]) | Convert the table to presence/absence data
  `partition`(f[, axis]) | Yields partitions
  `reduce`(f, axis) | Reduce over axis using function f
  `sort`([sort_f, axis]) | Return a table sorted along axis
  `sort_order`(order[, axis]) | Return a new table with axis in order
  `subsample`(n[, axis, by_id]) | Randomly subsample without replacement.
  `sum`([axis]) | Returns the sum by axis
  `to_hdf5`(h5grp, generated_by[, compress]) | Store CSC and CSR in place
  `to_json`(generated_by[, direct_io]) | Returns a JSON string representing the table in BIOM format.
  `to_tsv`([header_key, header_value, ...]) | Return self as a string in tab delimited form
  `transform`(f[, axis, inplace]) | Iterate over axis, applying a function f to each vector.
  `transpose`() | Transpose the contingency table
  `update_ids`(id_map[, axis, strict, inplace]) | Update the ids along the given axis